@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: principals.py 1184 2009-05-12 18:39:39Z mac $
+# $Id: principals.py 688 2009-11-21 15:07:47Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.addressbook.browser.base
+import icemac.addressbook.browser.metadata
 import icemac.addressbook.browser.table
 import icemac.addressbook.principals.interfaces
 import icemac.addressbook.principals.principals
@@ -12,21 +13,17 @@ import transaction
 import z3c.form.button
 import z3c.form.field
 import z3c.form.widget
-import z3c.pagelet.browser
 import zope.interface
 import zope.schema
 import zope.schema.interfaces
 import zope.security
-import zope.traversing.browser.interfaces
 
-class Overview(z3c.pagelet.browser.BrowserPagelet,
-               icemac.addressbook.browser.table.Table):
+
+class Overview(icemac.addressbook.browser.table.PageletTable):
 
     no_rows_message = _(
         u'No users defined yet or you are not allowed to access any.')
 
-    update = icemac.addressbook.browser.table.Table.update
-
     def setUpColumns(self):
         return [
             z3c.table.column.addColumn(
@@ -62,26 +59,35 @@ class PersonFieldDataManager(z3c.form.datamanager.AttributeField):
         self.context.person = value
 
 
+def get_principal_entity():
+    entities_util = icemac.addressbook.browser.base.get_entities_util()
+    return entities_util.getEntity(
+        icemac.addressbook.principals.interfaces.IPrincipal)
+
+
 class AddForm(icemac.addressbook.browser.base.BaseAddForm):
 
     label = _(u'Add new user')
     class_ = icemac.addressbook.principals.principals.Principal
     next_url = 'parent'
-    fields = (
-        z3c.form.field.Fields(
-            icemac.addressbook.principals.interfaces.IPrincipal).select(
-            'person')
-        +
-        z3c.form.field.Fields(
-            icemac.addressbook.principals.interfaces.IPasswordFields)
-        +
-        z3c.form.field.Fields(
-            icemac.addressbook.principals.interfaces.IRoles)
-        +
-        z3c.form.field.Fields(
-            icemac.addressbook.principals.interfaces.IPrincipal).omit(
-            'login', 'person')
-        )
+
+    @property
+    def fields(self):
+        return (
+            z3c.form.field.Fields(
+                icemac.addressbook.principals.interfaces.IPrincipal).select(
+                'person')
+            +
+            z3c.form.field.Fields(
+                icemac.addressbook.principals.interfaces.IPasswordFields)
+            +
+            z3c.form.field.Fields(
+                icemac.addressbook.principals.interfaces.IRoles)
+            +
+            z3c.form.field.Fields(
+                *get_principal_entity().getFieldValuesInOrder()).omit(
+                'login', 'person')
+            )
 
     def add(self, obj):
         try:
@@ -102,24 +108,29 @@ password_not_required = z3c.form.widget.StaticWidgetAttribute(
     request=None, view=None, field=zope.schema.Password, widget=None)
 
 
-class EditForm(icemac.addressbook.browser.base.BaseEditFormWithCancel):
+class EditForm(z3c.form.group.GroupForm,
+               icemac.addressbook.browser.base.BaseEditFormWithCancel):
 
+    groups = (icemac.addressbook.browser.metadata.ModifiedGroup,)
     next_url = 'parent'
-    fields = (
-        z3c.form.field.Fields(
-            icemac.addressbook.principals.interfaces.IPrincipal).select(
-            'person', 'login')
-        +
-        z3c.form.field.Fields(
-            icemac.addressbook.principals.interfaces.IPasswordFields)
-        +
-        z3c.form.field.Fields(
-            icemac.addressbook.principals.interfaces.IRoles)
-        +
-        z3c.form.field.Fields(
-            icemac.addressbook.principals.interfaces.IPrincipal).omit(
-            'person', 'login')
-        )
+
+    @property
+    def fields(self):
+        return (
+            z3c.form.field.Fields(
+                icemac.addressbook.principals.interfaces.IPrincipal).select(
+                'person', 'login')
+            +
+            z3c.form.field.Fields(
+                icemac.addressbook.principals.interfaces.IPasswordFields)
+            +
+            z3c.form.field.Fields(
+                icemac.addressbook.principals.interfaces.IRoles)
+            +
+            z3c.form.field.Fields(
+                *get_principal_entity().getFieldValuesInOrder()).omit(
+                'person', 'login')
+            )
 
     @z3c.form.button.buttonAndHandler(_('Apply'), name='apply')
     def handleApply(self, action):
@@ -136,10 +147,7 @@ class EditForm(icemac.addressbook.browser.base.BaseEditFormWithCancel):
         condition=icemac.addressbook.browser.base.can_access(
             '@@delete_user.html'))
     def handleDeleteUser(self, action):
-        url = zope.component.getMultiAdapter(
-            (self.context, self.request),
-            zope.traversing.browser.interfaces.IAbsoluteURL)()
-        self.request.response.redirect(url + '/@@delete_user.html')
+        self.redirect_to_next_url('object', '@@delete_user.html')
 
     def applyChanges(self, data):
         try:
