@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 1124 2009-04-07 18:42:58Z mac $
+# $Id: tests.py 653 2009-11-01 17:00:43Z icemac $
 
 import unittest
 import zope.interface.verify
@@ -26,4 +26,9 @@ class TestInterfaces(unittest.TestCase):
 
 
 def test_suite():
-    return icemac.addressbook.testing.UnittestSuite(TestInterfaces)
+    suite = icemac.addressbook.testing.UnittestSuite(TestInterfaces)
+    suite.addTest(icemac.addressbook.testing.FunctionalDocFileSuite(
+        'export/export.txt',
+        'export/userfields.txt'))
+    return suite
+
